@@ -88,8 +88,8 @@ tidy_beta <- function(.n = 50, .shape1 = 1, .shape2 = 1, .ncp = 0, .num_sims = 1
     dplyr::mutate(d = list(density(unlist(y), n = n)[c("x", "y")] %>%
       purrr::set_names("dx", "dy") %>%
       dplyr::as_tibble())) %>%
-    dplyr::mutate(p = list(stats::pbeta(ps, shape1 = shape1, shape2 = shape2, ncp = ncp))) %>%
-    dplyr::mutate(q = list(stats::qbeta(tidy_scale_zero_one_vec(unlist(y)), shape1 = shape1, shape2 = shape2, ncp = ncp))) %>%
+    dplyr::mutate(p = list(stats::pbeta(unlist(y), shape1 = shape1, shape2 = shape2, ncp = ncp))) %>%
+    dplyr::mutate(q = list(stats::qbeta(unlist(p), shape1 = shape1, shape2 = shape2, ncp = ncp))) %>%
     tidyr::unnest(cols = c(x, y, d, p, q)) %>%
     dplyr::ungroup()
 
