@@ -91,8 +91,8 @@ tidy_pareto <- function(.n = 50, .shape = 10, .scale = 0.1, .num_sims = 1) {
     dplyr::mutate(d = list(density(unlist(y), n = n)[c("x", "y")] %>%
       purrr::set_names("dx", "dy") %>%
       dplyr::as_tibble())) %>%
-    dplyr::mutate(p = list(actuar::ppareto(ps, shape = shape, scale = scale))) %>%
-    dplyr::mutate(q = list(actuar::qpareto(tidy_scale_zero_one_vec(unlist(y)), shape = shape, scale = scale))) %>%
+    dplyr::mutate(p = list(actuar::ppareto(unlist(y), shape = shape, scale = scale))) %>%
+    dplyr::mutate(q = list(actuar::qpareto(unlist(p), shape = shape, scale = scale))) %>%
     tidyr::unnest(cols = c(x, y, d, p, q)) %>%
     dplyr::ungroup()
 
